package cn.com.v2.controller;


import cn.com.v2.common.base.BaseController;
import cn.com.v2.common.domain.AjaxResult;
import cn.com.v2.model.CommonQuestion;
import cn.com.v2.service.CommonQuestionService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;

/**
 * 常见问题(TCommonQuestion)表控制层
 *
 * @author wu
 * @since 2025-04-21 09:36:06
 */
@RestController
@RequestMapping("/api/goview/commonQuestion")
@Api(tags = "常见问题")
@Transactional(rollbackFor = Exception.class)
public class CommonQuestionController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private CommonQuestionService commonQuestionService;

    /**
     * 分页条件查询所有数据
     *
     * @param page            分页条件
     * @param commonQuestion 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询常见问题", response = CommonQuestion.class)
    public AjaxResult page(Page<CommonQuestion> page, CommonQuestion commonQuestion) {
        return successData(200, commonQuestionService.page(page, new QueryWrapper<>(commonQuestion)));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条常见问题", response = CommonQuestion.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return successData(200, commonQuestionService.getById(id));
    }


    /**
     * 新增数据
     *
     * @param commonQuestion 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增常见问题", response = CommonQuestion.class)
    public AjaxResult insert(@RequestBody CommonQuestion commonQuestion) {
        return successData(200, commonQuestionService.save(commonQuestion));
    }

    /**
     * 修改数据
     *
     * @param commonQuestion 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改常见问题")
    public AjaxResult update(@RequestBody CommonQuestion commonQuestion) {
        return successData(200, commonQuestionService.updateById(commonQuestion));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @DeleteMapping("{id}")
    @ApiOperation(value = "删除常见问题")
    public AjaxResult delete(@PathVariable Serializable id) {
        return successData(200, commonQuestionService.removeById(id));
    }
}

