package cn.com.v2.controller;


import cn.com.v2.common.base.BaseController;
import cn.com.v2.common.domain.AjaxResult;
import cn.com.v2.model.Dictionary;
import cn.com.v2.service.DictionaryService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;

/**
 * 字典(Dictionary)表控制层
 *
 * @author wu
 * @since 2025-04-21 14:18:31
 */
@RestController
@RequestMapping("/api/goview/dictionary")
@Api(tags = "字典")
@Transactional(rollbackFor = Exception.class)
public class DictionaryController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private DictionaryService dictionaryService;

    /**
     * 分页条件查询所有数据
     *
     * @param page       分页条件
     * @param dictionary 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询字典", response = Dictionary.class)
    public AjaxResult page(Page<Dictionary> page, Dictionary dictionary) {
        return successData(200, dictionaryService.page(page, new QueryWrapper<>(dictionary)));
    }

    /**
     * 根据字典类型查询字典
     *
     * @param dictType 字典类型
     * @return 所有数据
     */
    @GetMapping("/findByType")
    @ApiOperation(value = "根据字典类型查询字典", response = Dictionary.class)
    public AjaxResult findByType(String dictType) {
        QueryWrapper<Dictionary> wrapper = new QueryWrapper<>();
        wrapper.eq("dict_type", dictType);
        return successData(200, dictionaryService.list(wrapper));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条字典", response = Dictionary.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return successData(200, dictionaryService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param dictionary 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增字典", response = Dictionary.class)
    public AjaxResult insert(@RequestBody Dictionary dictionary) {
        return successData(200, dictionaryService.save(dictionary));
    }

    /**
     * 修改数据
     *
     * @param dictionary 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改字典")
    public AjaxResult update(@RequestBody Dictionary dictionary) {
        return successData(200, dictionaryService.updateById(dictionary));
    }

    /**
     * 删除数据
     *
     * @param id 主键
     * @return 删除结果
     */
    @DeleteMapping("{id}")
    @ApiOperation(value = "删除字典")
    public AjaxResult delete(@PathVariable Serializable id) {
        return successData(200, dictionaryService.removeById(id));
    }
}

